@@ -8,12 +8,46 @@ Coordinates are (lon, lat) to match (x, y)
 Bounding box order is  (left, bottom, right, top) (floats)
 """
 from __future__ import division, print_function
+import json
 import itertools
-import shapely.geometry
+from shapely import geometry, wkt
 
 
 def geojson_to_wkt(gj):
-    return shapely.geometry.shape(gj).wkt
+    """Convert a geojson dict to a WKT string"""
+    try:
+        return geometry.shape(gj).wkt
+    except ValueError:
+        return geometry.shape(gj["geometry"]).wkt
+
+
+def bbox_to_wkt(bbox):
+    """Convert (left, bot, right, top) bbox to a WKT string"""
+    return geometry.box(*bbox).wkt
+
+
+def load_bbox(bbox_file):
+    """Return a bounding box rectangle from .wkt or .geojson files"""
+    if bbox_file:
+        with open(bbox_file) as f:
+            if bbox_file.endswith(".wkt"):
+                return tuple(wkt.load(f).bounds)
+            elif bbox_file.endswith("json"):
+                gj = json.load(f)
+                try:
+                    return tuple(gj["bbox"])
+                except KeyError:
+                    try:
+                        return tuple(geometry.shape(gj["geometry"]).bounds)
+                    except KeyError:
+                        return tuple(geometry.shape(gj).bounds)
+
+            else:
+                raise ValueError(
+                    "Unknown file format for bbox (need .wkt or .geojson): {}".format(
+                        bbox_file
+                    )
+                )
 
 
 def bounding_box(geojson=None, top_corner=None, dlon=None, dlat=None, filename=None):
@@ -37,6 +71,7 @@ def bounding_box(geojson=None, top_corner=None, dlon=None, dlat=None, filename=N
 
     if filename:
         import rasterio as rio  # only spend import if needed
+
         with rio.open(filename, "r") as src:
             return list(src.bounds)
 
@@ -46,13 +81,16 @@ def bounding_box(geojson=None, top_corner=None, dlon=None, dlat=None, filename=N
         coordinates = corner_coords(top_corner=top_corner, dlon=dlon, dlat=dlat)
     else:
         coordinates = coords(geojson)
+    # https://stackoverflow.com/a/20100700/4174466
+    return geometry.MultiPoint(coordinates).bounds
 
-    left = min(float(lon) for (lon, lat) in coordinates)
-    right = max(float(lon) for (lon, lat) in coordinates)
 
-    top = max(float(lat) for (lon, lat) in coordinates)
-    bottom = min(float(lat) for (lon, lat) in coordinates)
-    return left, bottom, right, top
+bbox = bounding_box
+
+
+def bbox_to_geojson(bbox):
+    """Convert a (left, bot, right, top) bounding box to geojson string"""
+    return json.dumps(geometry.mapping(geometry.box(*bbox)))
 
 
 def corner_coords(top_corner=None, dlon=None, dlat=None, bot_corner=None):
@@ -95,8 +133,7 @@ def extent(geojson):
 
 
 def corners_to_geojson(corners):
-    """Takes in 5 points for the corners, returns geojson
-    """
+    """Takes in 5 points for the corners, returns geojson"""
     return {"type": "Polygon", "coordinates": [corners]}
 
 
@@ -116,14 +153,14 @@ def coords(geojson):
     """
     # First, if given a deeper object (e.g. from geojson.io), extract just polygon
     try:
-        if geojson.get('type') == 'FeatureCollection':
-            geojson = geojson['features'][0]['geometry']
-        elif geojson.get('type') == 'Feature':
-            geojson = geojson['geometry']
+        if geojson.get("type") == "FeatureCollection":
+            geojson = geojson["features"][0]["geometry"]
+        elif geojson.get("type") == "Feature":
+            geojson = geojson["geometry"]
     except KeyError:
         raise ValueError("Invalid geojson")
 
-    return geojson['coordinates'][0]
+    return geojson["coordinates"][0]
 
 
 def format_coords(geojson_dict, decimals=4):
@@ -140,20 +177,21 @@ def format_coords(geojson_dict, decimals=4):
         str: lon,lat points of the Polygon in order as 'lon1,lat1,lon2,lat2,...'
     """
     c = coords(geojson_dict)
-    fmt_str = '{{0:.{decimals}f}}'.format(decimals=decimals)
-    return ','.join(fmt_str.format(coord) for coord in itertools.chain.from_iterable(c))
+    fmt_str = "{{0:.{decimals}f}}".format(decimals=decimals)
+    return ",".join(fmt_str.format(coord) for coord in itertools.chain.from_iterable(c))
 
 
 def kml_string_fmt(gj_dict):
     # Example coord_string:
     # -102.2,29.5 -101.4,29.5 -101.4,28.8 -102.2,28.8 -102.2,29.5
     coord_list = coords(gj_dict)
-    return ' '.join(map(lambda tup: ','.join((str(s) for s in tup)), coord_list))
+    return " ".join(map(lambda tup: ",".join((str(s) for s in tup)), coord_list))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import sys
     import json
+
     try:
         gj_file = sys.argv[1]
     except IndexError:
