@@ -2,25 +2,25 @@
 Utilities for parsing file names of SAR products for relevant info.
 
 """
-from __future__ import division, print_function
-import os
-import re
-import pprint
-from datetime import datetime
 
-import apertools.latlon
+from genericpath import exists
+import re
+from datetime import datetime
+import os
+import pprint
+
 from apertools.log import get_log
+
 logger = get_log()
 
-__all__ = ['Sentinel', 'Uavsar', 'SentinelOrbit']
+__all__ = ["Sentinel", "Uavsar", "SentinelOrbit"]
 
 
 class Base(object):
-    """Base parser to illustrate expected interface/ minimum data available
-    """
+    """Base parser to illustrate expected interface/ minimum data available"""
+
     FILE_REGEX = None
     TIME_FMT = None
-    _FIELD_MEANINGS = None
 
     def __init__(self, filename, verbose=False):
         """
@@ -45,7 +45,7 @@ class Base(object):
         """Returns all parts of the data contained in filename
 
         Returns:
-            tuple: parsed file data. Entry order will match `field_meanings`
+            tuple: parsed file data. Entry order will match reged named fields
 
         Raises:
             ValueError: if filename string is invalid
@@ -55,20 +55,24 @@ class Base(object):
 
         match = re.search(self.FILE_REGEX, self.filename)
         if not match:
-            raise ValueError('Invalid {} filename: {}'.format(self.__class__.__name__,
-                                                              self.filename))
+            raise ValueError(
+                "Invalid {} filename: {}".format(self.__class__.__name__, self.filename)
+            )
         else:
-            return match.groups()
+            return match.groupdict()
 
     @property
     def field_meanings(self):
         """List the fields returned by full_parse()"""
-        return self._FIELD_MEANINGS
+        return self.full_parse().keys()
 
     def _get_field(self, fieldname):
         """Pick a specific field based on its name"""
-        idx = self.field_meanings.index(fieldname)
-        return self.full_parse()[idx]
+        return self.full_parse()[fieldname]
+
+    def __getitem__(self, item):
+        """Access properties with uavsar[item] syntax"""
+        return self._get_field(item)
 
 
 class Sentinel(Base):
@@ -105,47 +109,36 @@ class Sentinel(Base):
     Attributes:
         filename (str) name of the sentinel data product
     """
-    FILE_REGEX = r'(S1A|S1B)_([\w\d]{2})_([\w_]{3})([FHM_])_([012])S([SDHV]{2})_([T\d]{15})_([T\d]{15})_(\d{6})_([\d\w]{6})_([\d\w]{4})'
-    TIME_FMT = '%Y%m%dT%H%M%S'
-    _FIELD_MEANINGS = (
-        'mission',
-        'beam',
-        'product type',
-        'resolution class',
-        'product level',
-        'polarization',
-        'start datetime',
-        'stop datetime',
-        'orbit number',
-        'data-take identified',
-        'product unique id',
+
+    FILE_REGEX = re.compile(
+        r"(?P<mission>S1A|S1B)_"
+        r"(?P<beam>[\w\d]{2})_"
+        r"(?P<product_type>[\w_]{3})"
+        r"(?P<resolution_class>[FHM_])_"
+        r"(?P<product_level>[012])S"
+        r"(?P<polarization>[SDHV]{2})_"
+        r"(?P<start_datetime>[T\d]{15})_"
+        r"(?P<stop_datetime>[T\d]{15})_"
+        r"(?P<orbit_number>\d{6})_"
+        r"(?P<datetake_identifier>[\d\w]{6})_"
+        r"(?P<unique_id>[\d\w]{4})"
     )
+    TIME_FMT = "%Y%m%dT%H%M%S"
 
     def __init__(self, filename, **kwargs):
         super(Sentinel, self).__init__(filename, **kwargs)
-        # The name of the unzipped .SAFE directory (with .zip stripped)
-        self._safe_dir = self._form_safe_dir(filename)
-        self._preview_folder = os.path.join(self._safe_dir, 'preview')
-        self.map_overlay_kml = os.path.join(self._preview_folder, 'map-overlay.kml')
-        self._lon_lat_overlay_coords = apertools.latlon.map_overlay_coords(self.map_overlay_kml)
-
-    def _form_safe_dir(self, filename):
-        """Get just the Sentinel product name without extensions, then add .SAFE"""
-        # Strip '/' from end to start in case they pass "blahblah.SAFE/", or splitext[1] is ''
-        fname = filename.rstrip('/').replace('.zip', '').replace('.geo', '')
-        root, ext = os.path.splitext(fname)
-        return root + '.SAFE'
 
     def __str__(self):
-        return "{} {}, path {} from {}".format(self.__class__.__name__, self.mission, self.path,
-                                               self.date)
+        return "{} {}, path {} from {}".format(
+            self.__class__.__name__, self.mission, self.path, self.date
+        )
 
     def __lt__(self, other):
         return (self.start_time, self.filename) < (other.start_time, other.filename)
 
     def __eq__(self, other):
-        # TODO: Do we just want to compare product_uids?? or filenames?
         return self.product_uid == other.product_uid
+        # TODO: Is there ever a need to compare filenames? or just product_uids?
         # return self.filename == other.filename
 
     def __hash__(self):
@@ -155,37 +148,24 @@ class Sentinel(Base):
     def start_time(self):
         """Returns start datetime from a sentinel file name
 
-        Args:
-            filename (str): filename of a sentinel 1 product
-
-        Returns:
-            datetime: start datetime of mission
-
-
         Example:
             >>> s = Sentinel('S1A_IW_SLC__1SDV_20180408T043025_20180408T043053_021371_024C9B_1B70')
             >>> print(s.start_time)
             2018-04-08 04:30:25
         """
-        start_time_str = self._get_field('start datetime')
+        start_time_str = self._get_field("start_datetime")
         return datetime.strptime(start_time_str, self.TIME_FMT)
 
     @property
     def stop_time(self):
         """Returns stop datetime from a sentinel file name
 
-        Args:
-            filename (str): filename of a sentinel 1 product
-
-        Returns:
-            datetime: stop datetime
-
         Example:
             >>> s = Sentinel('S1A_IW_SLC__1SDV_20180408T043025_20180408T043053_021371_024C9B_1B70')
             >>> print(s.stop_time)
             2018-04-08 04:30:53
         """
-        stop_time_str = self._get_field('stop datetime')
+        stop_time_str = self._get_field("stop_datetime")
         return datetime.strptime(stop_time_str, self.TIME_FMT)
 
     @property
@@ -197,7 +177,7 @@ class Sentinel(Base):
             >>> print(s.polarization)
             DV
         """
-        return self._get_field('polarization')
+        return self._get_field("polarization")
 
     @property
     def product_type(self):
@@ -208,7 +188,7 @@ class Sentinel(Base):
             >>> print(s.product_type)
             SLC
         """
-        return self._get_field('product type')
+        return self._get_field("product_type")
 
     @property
     def level(self):
@@ -224,7 +204,7 @@ class Sentinel(Base):
             >>> print(s.mission)
             S1A
         """
-        return self._get_field('mission')
+        return self._get_field("mission")
 
     @property
     def absolute_orbit(self):
@@ -235,7 +215,7 @@ class Sentinel(Base):
             >>> print(s.absolute_orbit)
             21371
         """
-        return int(self._get_field('orbit number'))
+        return int(self._get_field("orbit_number"))
 
     @property
     def relative_orbit(self):
@@ -252,9 +232,9 @@ class Sentinel(Base):
             >>> print(s.relative_orbit)
             160
         """
-        if self.mission == 'S1A':
+        if self.mission == "S1A":
             return ((self.absolute_orbit - 73) % 175) + 1
-        elif self.mission == 'S1B':
+        elif self.mission == "S1B":
             return ((self.absolute_orbit - 27) % 175) + 1
 
     @property
@@ -265,60 +245,54 @@ class Sentinel(Base):
     @property
     def product_uid(self):
         """Unique identifier of product (last 4 of filename)"""
-        return self._get_field('product unique id')
+        return self._get_field("unique_id")
 
     @property
     def date(self):
         """Date of acquisition: shortcut for start_time.date()"""
         return self.start_time.date()
 
-    @property
-    def swath_extent(self):
-        """Give the lon and lat boundaries for the swath
+    def get_overlay_extent(self):
+        """Get the extent of the Sentinel L1 frame from the preview/map-overlay.kml file
 
-        Matches latlon.grid_extent(**dem_rsc_data)
-        (lon_left,lon_right,lat_bottom,lat_top)
+        Raises:
+            ValueError: If `self.filename` SAFE folder has no preview/map-overlay.kml
+
+        Returns:
+            list[tuple[float]]: 4 coordinates of frame corners as [(lon1, lat1), ...]
         """
-        if not os.path.exists(self.map_overlay_kml):
-            raise ValueError("No map-overlay.kml file found in %s" % self._preview_folder)
-        lons, lats = list(zip(*self._lon_lat_overlay_coords))
-        return min(lons), max(lons), min(lats), max(lats)
+        from xml.etree import ElementTree
 
-    @property
-    def extent(self):
-        """alias for swath_extent"""
-        return self.swath_extent
+        # The name of the unzipped .SAFE directory (with .zip stripped)
+        # Strip '/' from end to start in case they pass "blahblah.SAFE/", or splitext[1] is ''
+        fname = str(self.filename).rstrip("/").replace(".zip", "").replace(".geo", "")
+        root, _ = os.path.splitext(fname)
+        _safe_dir = root + ".SAFE"
+        _preview_folder = os.path.join(_safe_dir, "preview")
+        map_overlay_kml = os.path.join(_preview_folder, "map-overlay.kml")
+        # Check that they have all the necessary kmls
+        if not os.path.exists(map_overlay_kml):
+            raise ValueError(f"{map_overlay_kml} does not exist to get extent")
 
-    @property
-    def swath_width_height(self):
-        """Width and height of the swath area in degrees"""
-        left, right, bot, top = self.swath_extent
-        return right - left, top - bot
+        etree = ElementTree.parse(map_overlay_kml)
 
-    def overlaps_dem(self, dem_rsc_data):
-        """Swath is contained in DEM from rsc data"""
-        dem_extent = apertools.latlon.grid_extent(**dem_rsc_data)
-        return apertools.latlon.intersects(self.swath_extent, dem_extent)
+        root = etree.getroot()
+        # point_str looks like:
+        # <coordinates>-102.552971,31.482372 -105.191353,31.887299...
+        point_str = list(elem.text for elem in root.iter("coordinates"))[0]
+        return [
+            (float(lon), float(lat))
+            for lon, lat in [p.split(",") for p in point_str.split()]
+        ]
 
-    def overlaps_geojson(self, geojson):
-        """Swath is contained in bounding box for geojson"""
-        if isinstance(geojson, str):
-            geojson = apertools.sario.load(geojson)
+    def get_swath_bbox(self):
+        """Get the outer bounding box of Sentinel frame
 
-        geojson_extent = apertools.geojson.extent(geojson)
-        return apertools.latlon.intersects(self.swath_extent, geojson_extent)
-
-    def overlaps(self, geojson_or_rsc):
-        """Swath is contained in DEM or geojson (parsed to figure out which is passed)"""
-        if 'x_first' in [k.lower() for k in geojson_or_rsc.keys()]:
-            return self.overlaps_dem(geojson_or_rsc)
-
-        # Test for geojson by extracting the coords
-        try:
-            apertools.geojson.coords(geojson_or_rsc)
-        except ValueError:
-            raise ValueError("Need either valid geojson or dem_rsc_data")
-        return self.overlaps_geojson(geojson_or_rsc)
+        Returns:
+            tuple[float]: (left, bottom, right, top) of bounding box
+        """
+        lons, lats = zip(*self.get_overlay_extent())
+        return (min(lons), min(lats), max(lons), max(lats))
 
 
 class SentinelOrbit(Base):
@@ -356,17 +330,23 @@ class SentinelOrbit(Base):
     Attributes:
         filename (str) name of the sentinel data product
     """
-    FILE_REGEX = r'(S1A|S1B)_OPER_AUX_([\w_]{6})_OPOD_([T\d]{15})_V([T\d]{15})_([T\d]{15}).EOF'
-    TIME_FMT = '%Y%m%dT%H%M%S'
-    _FIELD_MEANINGS = ('mission', 'orbit type', 'created datetime', 'start datetime',
-                       'stop datetime')
+
+    TIME_FMT = "%Y%m%dT%H%M%S"
+    FILE_REGEX = (
+        r"(?P<mission>S1A|S1B)_OPER_AUX_"
+        r"(?P<orbit_type>[\w_]{6})_OPOD_"
+        r"(?P<created_datetime>[T\d]{15})_"
+        r"V(?P<start_datetime>[T\d]{15})_"
+        r"(?P<stop_datetime>[T\d]{15})"
+    )
 
     def __init__(self, filename, **kwargs):
         super(SentinelOrbit, self).__init__(filename, **kwargs)
 
     def __str__(self):
-        return "{} {} from {} to {}".format(self.orbit_type, self.__class__.__name__,
-                                            self.start_time, self.stop_time)
+        return "{} {} from {} to {}".format(
+            self.orbit_type, self.__class__.__name__, self.start_time, self.stop_time
+        )
 
     def __lt__(self, other):
         return (self.start_time, self.filename) < (other.start_time, other.filename)
@@ -376,12 +356,7 @@ class SentinelOrbit(Base):
         return self.start_time < dt < self.stop_time
 
     def __eq__(self, other):
-        return (
-            self.mission,
-            self.start_time,
-            self.stop_time,
-            self.orbit_type,
-        ) == (
+        return (self.mission, self.start_time, self.stop_time, self.orbit_type,) == (
             other.mission,
             other.start_time,
             other.stop_time,
@@ -397,60 +372,42 @@ class SentinelOrbit(Base):
             >>> print(s.mission)
             S1A
         """
-        return self._get_field('mission')
+        return self._get_field("mission")
 
     @property
     def start_time(self):
         """Returns start datetime of an orbit
 
-        Args:
-            filename (str): filename of a sentinel 1 EOF file
-
-        Returns:
-            datetime: start datetime of mission
-
         Example:
             >>> s = SentinelOrbit('S1A_OPER_AUX_POEORB_OPOD_20200121T120654_V20191231T225942_20200102T005942.EOF')
             >>> print(s.start_time)
             2019-12-31 22:59:42
         """
-        start_time_str = self._get_field('start datetime')
+        start_time_str = self._get_field("start_datetime")
         return datetime.strptime(start_time_str, self.TIME_FMT)
 
     @property
     def stop_time(self):
         """Returns stop datetime from a sentinel file name
 
-        Args:
-            filename (str): filename of a sentinel 1 product
-
-        Returns:
-            datetime: stop datetime
-
         Example:
             >>> s = SentinelOrbit('S1A_OPER_AUX_POEORB_OPOD_20200121T120654_V20191231T225942_20200102T005942.EOF')
             >>> print(s.stop_time)
             2020-01-02 00:59:42
         """
-        stop_time_str = self._get_field('stop datetime')
+        stop_time_str = self._get_field("stop_datetime")
         return datetime.strptime(stop_time_str, self.TIME_FMT)
 
     @property
     def created_time(self):
         """Returns created datetime from a orbit file name
 
-        Args:
-            filename (str): filename of a sentinel 1 product
-
-        Returns:
-            datetime: created datetime
-
         Example:
             >>> s = SentinelOrbit('S1A_OPER_AUX_POEORB_OPOD_20200121T120654_V20191231T225942_20200102T005942.EOF')
             >>> print(s.created_time)
             2020-01-21 12:06:54
         """
-        stop_time_str = self._get_field('created datetime')
+        stop_time_str = self._get_field("created_datetime")
         return datetime.strptime(stop_time_str, self.TIME_FMT)
 
     @property
@@ -465,13 +422,13 @@ class SentinelOrbit(Base):
         >>> print(s.orbit_type)
         restituted
         """
-        o = self._get_field('orbit type')
-        if o == 'POEORB':
-            return 'precise'
-        elif o == 'RESORB':
-            return 'restituted'
-        elif o == 'PREORB':
-            return 'predicted'
+        o = self._get_field("orbit_type")
+        if o == "POEORB":
+            return "precise"
+        elif o == "RESORB":
+            return "restituted"
+        elif o == "PREORB":
+            return "predicted"
         else:
             raise ValueError("unknown orbit type: %s" % self.filename)
 
@@ -507,30 +464,31 @@ class Uavsar(Base):
         >>> parser = Uavsar(fname)
 
     """
-    FILE_REGEX = r'([\w\d]{6})_(\d{3})(\w+)_(\d{2})(\d{3})_(\d{3})_(\d{6})_(\w)(\d{3})(\w{0,4})_(XX|CX)_(\w{2})(_ML\dX\d)?'
-    TIME_FMT = '%y%m%d'
-    _FIELD_MEANINGS = (
-        'target site',
-        'heading',
-        'counter',
-        'flight year',
-        'flight number',
-        'flight line',
-        'date',
-        'frequency band',
-        'steering angle',
-        'polarization',
-        'cross talk',
-        'version number',
-        'downsampling',
+
+    FILE_REGEX = (
+        r"(?P<target_site>[\w\d]{6})_"
+        # r"(?P<heading>\d{3})(?P<counter>\w+)_" # this is lineID
+        r"(?P<line_id>\d{5})_"
+        # r"(?P<year>\d{2})(?P<flight_number>\d{3})_" # this is FlightID
+        r"(?P<flight_id>\d{5})_"
+        r"(?P<data_take>\d{3})_"
+        r"(?P<date>\d{6})_"
+        r"(?P<band_squint_pol>\w{0,8})_"
+        r"(?P<xtalk>X|C)(?P<dither>[XGD])_"
+        r"(?P<nmode>\w{3,4})?_?"
+        r"(?P<version>\d{2})"
+        r"(_ML)?(?P<multilook>\dX\d)?"
+        r"\.?(?P<ext>\w{2,5})?"
     )
+    TIME_FMT = "%y%m%d"
     # Filetype of real or complex depends on the polarization for .grd, .mlc
-    REAL_POLS = ('HHHH', 'HVHV', 'VVVV')
-    COMPLEX_POLS = ('HHHV', 'HHVV', 'HVVV')
+    REAL_POLS = ("HHHH", "HVHV", "VVVV")
+    COMPLEX_POLS = ("HHHV", "HHVV", "HVVV")
     POLARIZATIONS = REAL_POLS + COMPLEX_POLS
 
     def __str__(self):
-        return "{} {} from {}".format(self.__class__.__name__, self.polarization, self.date)
+        return self.filename
+        return "{} from {}".format(self.__class__.__name__, self.date)
 
     @property
     def date(self):
@@ -546,7 +504,7 @@ class Uavsar(Base):
             >>> parser.date
             datetime.date(2008, 7, 31)
         """
-        date_str = self._get_field('date')
+        date_str = self._get_field("date")
         return datetime.strptime(date_str, self.TIME_FMT).date()
 
     @property
@@ -563,27 +521,28 @@ class Uavsar(Base):
             >>> Uavsar('brazos_14938_17087_004_170831_L090_CX_01_grd.zip').polarization
             ''
         """
-        return self._get_field('polarization')
+        bsq = self._get_field("band_squint_pol")
+        return None if not bsq else bsq[4:]
 
     @property
     def target_site(self):
         """Target site of acquisition"""
-        return self._get_field('target site')
+        return self._get_field("target_site")
 
     @property
-    def downsampling(self):
-        """Amount of downsampling of product, if any
+    def multilook(self):
+        """Number of looks taken in product, if any
 
         Examples:
-        >>> print(Uavsar('brazos_14938_17087_004_170831_L090_CX_01_grd.zip').downsampling)
+        >>> print(Uavsar('brazos_14938_17087_004_170831_L090_CX_01_grd.zip').multilook)
         None
-        >>> Uavsar('brazos_14938_17087_004_170831_L090_CX_01_ML5X5_grd.zip').downsampling
+        >>> Uavsar('brazos_14938_17087_004_170831_L090_CX_01_ML5X5_grd.zip').multilook
         '5X5'
-        >>> Uavsar('brazos_14938_17087_004_170831_L090HHHV_CX_01_ML3X3.grd').downsampling
+        >>> Uavsar('brazos_14938_17087_004_170831_L090HHHV_CX_01_ML3X3.grd').multilook
         '3X3'
         """
-        sample_str = self._get_field('downsampling')
-        return sample_str.replace('_ML', '') if sample_str else None
+        sample_str = self._get_field("multilook")
+        return sample_str.replace("_ML", "") if sample_str else None
 
     def _make_ann_filename(self):
         """Take the name of a data file and return corresponding .ann name
@@ -600,18 +559,18 @@ class Uavsar(Base):
         # The .mlc and .grd files have polarization added to filename, .ann files don't
         shortname = self.filename
         for p in self.POLARIZATIONS:
-            shortname = shortname.replace(p, '')
+            shortname = shortname.replace(p, "")
 
         ext = os.path.splitext(shortname)[1]
         # If this is a block we split up and names .1.int, remove that since
         # all have the same .ann file
-        shortname = re.sub(r'\.\d' + ext, ext, shortname)
+        shortname = re.sub(r"\.\d" + ext, ext, shortname)
         if ext == ".grd":
             # .int.grd is full ext
-            full_ext = '.'.join(shortname.split('.')[1:])
-            return shortname.replace(full_ext, 'ann')
+            full_ext = ".".join(shortname.split(".")[1:])
+            return shortname.replace(full_ext, "ann")
 
-        return shortname.replace(ext, '.ann')
+        return shortname.replace(ext, ".ann")
 
     @property
     def ann_filename(self):
@@ -628,27 +587,80 @@ class Uavsar(Base):
         return self.parse_ann_file()
 
     def parse_ann_file(self):
-        return parse_ann_file(self.ann_filename, filename=self.filename, verbose=self.verbose)
+        return parse_ann_file(
+            self.ann_filename, filename=self.filename, verbose=self.verbose
+        )
 
 
 class UavsarInt(Uavsar):
     """See https://uavsar.jpl.nasa.gov/science/documents/rpi-format.html"""
-    FILE_REGEX = r'([\w\d]{6})_(\d{2})(\d{3})_(\d{2})(\d{3})-(\d{3})_(\d{5})-(\d{3})_(\d{4})d_s01_([\w\d]{6,8})_(\d{2})'
-    _FIELD_MEANINGS = (
-        'target site',
-        'heading',
-        'counter',
-        'track1 year',
-        'track1 flight number',
-        'track1 flight line',
-        # TODO: fill in rest
-        'flight year',
-        'flight number',
-        'flight line',
+
+    FILE_REGEX = (
+        r"(?P<target_site>[\w\d]{6})_"
+        r"(?P<heading>\d{3})(?P<counter>\d{2})_"  # this is lineID
+        r"(?P<line_id1>\d{5})-(?P<flight_number1>\d{3})_"
+        r"(?P<line_id2>\d{5})-(?P<flight_number2>\d{3})_"
+        r"(?P<baseline_days>\d{4})d_s01_"
+        r"(?P<band_squint_pol>\w{0,8})_"
+        r"(?P<version>\d{2})\.?(?P<ext>\w{2,5})?"
     )
 
     def __str__(self):
-        return "{} from {}".format(self.__class__.__name__, self.target_site)
+        return "{} from {}: {} - {}".format(
+            self.__class__.__name__, self.target_site, self.line_id1, self.line_id2
+        )
+
+    @property
+    def line_id1(self):
+        """First pass line id"""
+        return self._get_field("line_id1")
+
+    @property
+    def line_id2(self):
+        """Second pass line id"""
+        return self._get_field("line_id2")
+
+
+class UavsarStack(Uavsar):
+    """See https://uavsar.jpl.nasa.gov/science/documents/stack-format.html
+
+    {site name}_{line ID}_{flight ID}_{data take counter}_{acquisition date}_{stack number}_
+    {band}{steering}{polarization}_{stack_version}_{baseline correction}_
+    {segment number}_{downsample factor}.slc
+    """
+
+    FILE_REGEX = (
+        r"(?P<target_site>[\w\d]{6})_"
+        r"(?P<line_id>\d{5})_"
+        r"(?P<flight_id>\d{5})_"
+        r"(?P<data_take>\d{3})_"
+        r"(?P<date>\d{6})_"
+        r"(?P<band_squint_pol>\w{0,8})_"
+        r"(?P<stack_version>\d{2})_"
+        r"(?P<baseline_correction>[B|U]C)_"
+        r"s(?P<segment_number>\d{0,4})_"
+        r"(?P<downsample_factor>[x\d]{0,4})"
+        r".?(?P<ext>\w{2,5})?"
+    )
+
+    def __str__(self):
+        return "{} from {} on {}".format(
+            self.__class__.__name__, self.target_site, self.date
+        )
+
+    @property
+    def baseline_correction(self):
+        """First pass line id"""
+        return (
+            "baseline corrected"
+            if self._get_field("baseline_correction") == "BC"
+            else "UC"
+        )
+
+    @property
+    def downsample_factor(self):
+        """Second pass line id"""
+        return self._get_field("downsample_factor")
 
 
 def parse_ann_file(ann_filename, filename=None, ext=None, verbose=False):
@@ -661,10 +673,11 @@ def parse_ann_file(ann_filename, filename=None, ext=None, verbose=False):
         dict: the annotation file parsed into a dict. If no annotation file
             can be found, None is returned
     """
+
     def _parse_line(line):
         wordlist = line.split()
         # Pick the entry after the equal sign when splitting the line
-        return wordlist[wordlist.index('=') + 1]
+        return wordlist[wordlist.index("=") + 1]
 
     def _parse_int(line):
         return int(_parse_line(line))
@@ -673,7 +686,7 @@ def parse_ann_file(ann_filename, filename=None, ext=None, verbose=False):
         return float(_parse_line(line))
 
     def _make_line_regex(ext, field):
-        return r'{}.{}'.format(line_keywords.get(ext), field)
+        return r"{}.{}".format(line_keywords.get(ext), field)
 
     if not ext:
         if not filename:
@@ -694,47 +707,47 @@ def parse_ann_file(ann_filename, filename=None, ext=None, verbose=False):
     ann_data = {}
     line_keywords = {
         # ext: line start term
-        '.slc': 'slc_mag',
-        '.mlc': 'mlc_mag',
-        '.int': 'slt',
-        '.unw': 'slt',
-        '.cor': 'slt',
-        '.amp': 'slt',
-        '.grd': 'grd_mag',
+        ".slc": "slc_mag",
+        ".mlc": "mlc_mag",
+        ".int": "slt",
+        ".unw": "slt",
+        ".cor": "slt",
+        ".amp": "slt",
+        ".grd": "grd_mag",
     }
     # Add extra .grd extensions
-    for e in ('.int', '.unw', '.cc', '.cor', '.amp1', '.amp2'):
-        line_keywords[e + '.grd'] = line_keywords['.grd']
+    for e in (".int", ".unw", ".cc", ".cor", ".amp1", ".amp2"):
+        line_keywords[e + ".grd"] = line_keywords[".grd"]
 
-    row_key = line_keywords.get(ext) + '.set_rows'
-    col_key = line_keywords.get(ext) + '.set_cols'
+    row_key = line_keywords.get(ext) + ".set_rows"
+    col_key = line_keywords.get(ext) + ".set_cols"
 
     # Peg position the nadir position of aircraft at middle of datatake
-    with open(ann_filename, 'r') as f:
+    with open(ann_filename, "r") as f:
         for line in f.readlines():
             if line.startswith(row_key):
-                ann_data['rows'] = _parse_int(line)
+                ann_data["rows"] = _parse_int(line)
                 # Also add .rsc equivalent for compatibility
-                ann_data['file_length'] = ann_data['rows']
+                ann_data["file_length"] = ann_data["rows"]
             elif line.startswith(col_key):
-                ann_data['cols'] = _parse_int(line)
-                ann_data['width'] = ann_data['cols']
+                ann_data["cols"] = _parse_int(line)
+                ann_data["width"] = ann_data["cols"]
             # Center Latitude of Upper Left Pixel of GRD image, or
             # range Offset(R0) from Peg in meters
             # Note: using convention of .rsc files for consitency
             # I.E. x_first, x_step, y_first, y_step
-            elif re.match(_make_line_regex(ext, 'row_addr'), line):
-                ann_data['y_first'] = _parse_float(line)
+            elif re.match(_make_line_regex(ext, "row_addr"), line):
+                ann_data["y_first"] = _parse_float(line)
             # Center Longitude of Upper Left Pixel
-            elif re.match(_make_line_regex(ext, 'col_addr'), line):
-                ann_data['x_first'] = _parse_float(line)
+            elif re.match(_make_line_regex(ext, "col_addr"), line):
+                ann_data["x_first"] = _parse_float(line)
             # GRD Latitude Pixel Spacing
             # the step is negative in the y (row) direction
-            elif re.match(_make_line_regex(ext, 'row_mult'), line):
-                ann_data['y_step'] = _parse_float(line)
+            elif re.match(_make_line_regex(ext, "row_mult"), line):
+                ann_data["y_step"] = _parse_float(line)
             # GRD Longitude Pixel Spacing or SLC R (range) Slant Post Spacing
-            elif re.match(_make_line_regex(ext, 'col_mult'), line):
-                ann_data['x_step'] = _parse_float(line)
+            elif re.match(_make_line_regex(ext, "col_mult"), line):
+                ann_data["x_step"] = _parse_float(line)
             # TODO: Add more parsing! whatever is useful from .ann file
 
     if verbose:
